# Support

If you need help with this project or have questions, please:

1. Check the documentation and if you dont find anything there: [![Join our Discord](https://img.shields.io/discord/1097720481970397356?label=JoinOurDiscord&logo=discord&logoColor=white&color=5865f2)](https://discord.gg/R4tqghAgSE).
2. Search the [existing issues](https://github.com/Josh-XT/AGiXT/issues) and [pull requests](https://github.com/Josh-XT/AGiXT/pulls).
3. Create a [new issue](https://github.com/Josh-XT/AGiXT/issues/new) if your question is not answered or your problem is not solved.

Please note that this project is maintained by volunteers who have limited availability. We'll do our best to address your questions and concerns in a timely manner.
